@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2003-2006,2007,2008 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2003-2012 CS-SI. All Rights Reserved.
 * Author: Nicolas Delon <nicolas.delon@prelude-ids.com>
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
@@ -826,8 +826,26 @@ int idmef_value_match(idmef_value_t *val1, idmef_value_t *val2, idmef_criterion_
 int idmef_value_check_operator(const idmef_value_t *value, idmef_criterion_operator_t op)
 {
         prelude_return_val_if_fail(value, prelude_error(PRELUDE_ERROR_ASSERTION));
+        return idmef_value_type_check_operator(value->type.id, op);
+}
 
-        return idmef_value_type_check_operator(&value->type, op);
+
+
+/**
+ * idmef_value_get_applicable_operators:
+ * @value: Pointer to a #idmef_value_t object.
+ * @result: Pointer where the result will be stored.
+ *
+ * Store all operator supported by @value in @result.
+ *
+ * Returns: 0 on success, a negative value if an error occured.
+ */
+
+int idmef_value_get_applicable_operators(const idmef_value_t *value, idmef_criterion_operator_t *result)
+{
+        prelude_return_val_if_fail(value, prelude_error(PRELUDE_ERROR_ASSERTION));
+
+        return idmef_value_type_get_applicable_operators(value->type.id, result);
 }
 
 
