@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2002-2012 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude library.
@@ -43,6 +43,10 @@
 
 #include <string.h> /* for memmove */
 
+#ifdef __cplusplus
+ extern "C" {
+#endif
+
 
 /*
  * Using memmove make the generated code substencially slower,
@@ -251,4 +255,8 @@ static inline int prelude_extract_characters_safe(const char **out, char *buf, s
         return 0;
 }
 
+#ifdef __cplusplus
+ }
+#endif
+
 #endif /* _LIBPRELUDE_EXTRACT_H */
