@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2001, 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2001-2012 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude library.
@@ -25,16 +25,17 @@
 #define _LIBPRELUDE_PRELUDE_IDENT_H
 
 #include "prelude-inttypes.h"
+#include "prelude-string.h"
 
 #ifdef __cplusplus
  extern "C" {
 #endif
-         
+
 typedef struct prelude_ident prelude_ident_t;
 
-uint64_t prelude_ident_inc(prelude_ident_t *ident);
+int prelude_ident_generate(prelude_ident_t *ident, prelude_string_t *out);
 
-uint64_t prelude_ident_dec(prelude_ident_t *ident);
+uint64_t prelude_ident_inc(prelude_ident_t *ident);
 
 void prelude_ident_destroy(prelude_ident_t *ident);
 
@@ -43,5 +44,5 @@ int prelude_ident_new(prelude_ident_t **ret);
 #ifdef __cplusplus
  }
 #endif
-         
+
 #endif /* _LIBPRELUDE_PRELUDE_IDENT_H */
